import { clamp } from '../utils';
import angle, { normalizeAngle } from './angle';
import { matchHslString } from './parsers/hslString';
import { rgbFromColorString } from './rgb';
import rgbToHsl from './transforms/rgbToHsl';
export function isHsl(color) {
  return typeof color.h === 'number' && typeof color.s === 'number' && typeof color.l === 'number' && typeof color.a === 'number';
}
export function normalizeHsl(hsl) {
  return {
    h: normalizeAngle(hsl.h),
    s: clamp(hsl.s, 0, 100),
    l: clamp(hsl.l, 0, 100),
    a: clamp(hsl.a, 0, 1)
  };
}

function hslFromParsedHslString(match) {
  const hslValues = match.map(val => parseFloat(val));
  let alpha = hslValues[3] ?? 1;

  if (match[3]?.indexOf('%') > -1) {
    alpha *= 0.01;
  }

  return normalizeHsl({
    h: angle(match[0]),
    s: hslValues[1],
    l: hslValues[2],
    a: alpha
  });
}

function hslFromRgbString(colorString) {
  const rgbColor = rgbFromColorString(colorString);
  return rgbColor ? rgbToHsl(rgbColor) : null;
}

export function hslFromColorString(colorString) {
  colorString = colorString.trim();
  let match;
  if ((match = matchHslString(colorString)) !== null) return hslFromParsedHslString(match);
  return null;
}
export default function hsl(colorString) {
  const hslObj = hslFromColorString(colorString) ?? hslFromRgbString(colorString);
  if (hslObj === null) throw new Error('Invalid color string');
  return hslObj;
}